# Generated by Django 4.2.18 on 2025-05-08 08:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0051_rasterstyle_rendering_engine'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='rasterstyle',
            name='rendering_engine',
        ),
    ]
