# Generated by Django 4.1.10 on 2024-02-26 12:28

from django.db import migrations, models
import geomanager.fields


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0042_alter_dataset_options_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='AdditionalMapBoundaryData',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('table_name', models.CharField(max_length=256, unique=True)),
                ('properties', models.JSONField()),
                ('geometry_type', models.CharField(max_length=100)),
                ('bounds', geomanager.fields.ListField(max_length=256)),
            ],
            options={
                'verbose_name': 'Additional Map Boundary Layer',
                'verbose_name_plural': 'Additional Map Boundary Layers',
            },
        ),
    ]
