# Generated by Django 4.2.10 on 2024-04-23 07:13

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0089_log_entry_data_json_null_to_object'),
        ('geomanager', '0046_colorvalue_show_on_legend_rasterstyle_legend_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='geomanagersettings',
            name='map_disclaimer_page',
            field=models.ForeignKey(blank=True, help_text='MapViewer Map disclaimer page for more details', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailcore.page', verbose_name='Map Disclaimer Page'),
        ),
        migrations.AddField(
            model_name='geomanagersettings',
            name='map_disclaimer_text',
            field=models.CharField(blank=True, default='The boundaries and names shown and the designations used on this map do not imply the expression of any opinion whatsoever concerning the legal status of any country, territory, city or area or of its authorities, or concerning the delimitation of its frontiers or boundaries', max_length=350, null=True, verbose_name='Map Disclaimer Text'),
        ),
        migrations.AlterField(
            model_name='rasterfilelayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-MM-dd HH:mm', 'Hour minute:second - (E.g 2023-01-01 00:00)'), ('yyyy-MM-dd', 'Day - (E.g 2023-01-01)'), ('pentadal', 'Pentadal - (E.g Jan 2023 - P1 1-5th)'), ('dekadal', 'Dekadal - (E.g Jan 2023 - D1 1-10th)'), ('yyyy-MM', 'Month number - (E.g 2023-01)'), ('MMMM yyyy', 'Month name - (E.g January 2023)'), ('yyyy', 'Year - (E.g 2023)')], default='yyyy-MM-dd HH:mm', max_length=100, null=True, verbose_name='Display Format for DateTime Selector'),
        ),
        migrations.AlterField(
            model_name='rasterstyle',
            name='legend_type',
            field=models.CharField(choices=[('basic', 'Basic'), ('choropleth', 'Choropleth Horizontal'), ('choropleth_vertical', 'Choropleth Vertical'), ('gradient', 'Gradient Horizontal'), ('gradient_vertical', 'Gradient Vertical')], default='choropleth_vertical', max_length=100, verbose_name='Legend Type'),
        ),
        migrations.AlterField(
            model_name='rastertilelayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-MM-dd HH:mm', 'Hour minute:second - (E.g 2023-01-01 00:00)'), ('yyyy-MM-dd', 'Day - (E.g 2023-01-01)'), ('pentadal', 'Pentadal - (E.g Jan 2023 - P1 1-5th)'), ('dekadal', 'Dekadal - (E.g Jan 2023 - D1 1-10th)'), ('yyyy-MM', 'Month number - (E.g 2023-01)'), ('MMMM yyyy', 'Month name - (E.g January 2023)'), ('yyyy', 'Year - (E.g 2023)')], max_length=100, null=True, verbose_name='Display Format for DateTime Selector'),
        ),
        migrations.AlterField(
            model_name='vectortilelayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-MM-dd HH:mm', 'Hour minute:second - (E.g 2023-01-01 00:00)'), ('yyyy-MM-dd', 'Day - (E.g 2023-01-01)'), ('pentadal', 'Pentadal - (E.g Jan 2023 - P1 1-5th)'), ('dekadal', 'Dekadal - (E.g Jan 2023 - D1 1-10th)'), ('yyyy-MM', 'Month number - (E.g 2023-01)'), ('MMMM yyyy', 'Month name - (E.g January 2023)'), ('yyyy', 'Year - (E.g 2023)')], max_length=100, null=True, verbose_name='Display Format for DateTime Selector'),
        ),
        migrations.AlterField(
            model_name='wmslayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-MM-dd HH:mm', 'Hour minute:second - (E.g 2023-01-01 00:00)'), ('yyyy-MM-dd', 'Day - (E.g 2023-01-01)'), ('pentadal', 'Pentadal - (E.g Jan 2023 - P1 1-5th)'), ('dekadal', 'Dekadal - (E.g Jan 2023 - D1 1-10th)'), ('yyyy-MM', 'Month number - (E.g 2023-01)'), ('MMMM yyyy', 'Month name - (E.g January 2023)'), ('yyyy', 'Year - (E.g 2023)')], max_length=100, null=True, verbose_name='Display Format for DateTime Selector'),
        ),
    ]
