# Generated by Django 4.1.10 on 2023-07-10 19:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0083_workflowcontenttype'),
        ('geomanager', '0005_delete_countryboundary_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='StationSettings',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('columns', models.JSONField(blank=True, null=True)),
                ('id_field', models.CharField(default='station_id', max_length=100)),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.site')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
