# Generated by Django 4.1.10 on 2024-01-16 09:53

from django.db import migrations, models
import geomanager.validators


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0040_alter_rasterfilelayer_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='dataset',
            name='order',
            field=models.IntegerField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name='rasterfilelayer',
            name='auto_ingest_custom_directory_name',
            field=models.CharField(blank=True, max_length=255, null=True, unique=True, validators=[geomanager.validators.validate_directory_name], verbose_name='Custom directory name'),
        ),
    ]
