# Generated by Django 4.1.10 on 2024-01-09 10:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0039_rasterfilelayer_order_rastertilelayer_order_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='rasterfilelayer',
            options={'ordering': ['order'], 'verbose_name': 'Raster File Layer', 'verbose_name_plural': 'Raster File Layers'},
        ),
        migrations.AlterModelOptions(
            name='rastertilelayer',
            options={'ordering': ['order'], 'verbose_name': 'Raster Tile Layer', 'verbose_name_plural': 'Raster Tile Layers'},
        ),
        migrations.AlterModelOptions(
            name='vectorfilelayer',
            options={'ordering': ['order'], 'verbose_name': 'Vector File Layer', 'verbose_name_plural': 'Vector File Layers'},
        ),
        migrations.AlterModelOptions(
            name='vectortilelayer',
            options={'ordering': ['order'], 'verbose_name': 'Vector Tile Layer', 'verbose_name_plural': 'Vector Tile Layers'},
        ),
        migrations.AlterModelOptions(
            name='wmslayer',
            options={'ordering': ['order'], 'verbose_name': 'WMS Layer', 'verbose_name_plural': 'WMS Layers'},
        ),
        migrations.AddField(
            model_name='rasterfilelayer',
            name='auto_ingest_custom_directory_name',
            field=models.CharField(blank=True, max_length=255, null=True, unique=True, verbose_name='Custom directory name'),
        ),
        migrations.AddField(
            model_name='rasterfilelayer',
            name='auto_ingest_use_custom_directory_name',
            field=models.BooleanField(default=False, verbose_name='Use custom directory name'),
        ),
    ]
